<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/plan.git

return [

	// P
	'plan_description' => 'Ce plugin améliore la page « Plan du site » de l’espace privé en affichant une structure dépliable et en permettant de filtrer par statut d’articles.
',
	'plan_nom' => 'Plan du site dans l’espace privé',
	'plan_slogan' => 'Améliore la page plan du site de l’espace privé',
];
